=============
django-avatar
=============

.. image:: https://badge.fury.io/py/django-avatar.svg
    :target: https://badge.fury.io/py/django-avatar

.. image:: https://readthedocs.org/projects/django-avatar/badge/?version=latest
    :target: http://django-avatar.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/grantmcconnaughey/django-avatar.svg
    :target: https://travis-ci.org/grantmcconnaughey/django-avatar

.. image:: https://coveralls.io/repos/grantmcconnaughey/django-avatar/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/grantmcconnaughey/django-avatar?branch=master

Django-avatar is a reusable application for handling user avatars.  It has the
ability to default to Gravatar if no avatar is found for a certain user.
Django-avatar automatically generates thumbnails and stores them to your default
file storage backend for retrieval later.

For more information see the documentation at http://django-avatar.readthedocs.org/
